(camera)=

# Camera

### camera_efficiency

Main functionality for the `camera_efficiency` module is to provide an interface to the `testeff` program provided by sim_telarray.
A {ref}`TelescopeModel <telescope-model>` and few more physical parameters (zenith angle, etc) are required inputs.

```{eval-rst}
.. automodule:: camera.camera_efficiency
   :members:
```

## Single photon-electron spectral analysis

### single_photon_electron_spectrum

```{eval-rst}
.. automodule:: camera.single_photon_electron_spectrum
   :members:
```
